"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var observable_1 = require("tns-core-modules/data/observable");
var app = require("tns-core-modules/application");
var DropInRequest = com.braintreepayments.api.dropin.DropInRequest;
function setupBraintreeAppDeligate(urlScheme) {
}
exports.setupBraintreeAppDeligate = setupBraintreeAppDeligate;
var Braintree = (function (_super) {
    __extends(Braintree, _super);
    function Braintree() {
        var _this = _super.call(this) || this;
        _this.output = {
            'status': 'fail',
            'msg': 'unknown',
            'nonce': '',
            'paymentMethodType': '',
            'deviceInfo': ''
        };
        return _this;
    }
    Braintree.prototype.startPayment = function (token, options) {
        var t = this;
        var activity = app.android.foregroundActivity || app.android.startActivity;
        var dropInRequest = new DropInRequest();
        if (options.amount) {
            dropInRequest.amount(options.amount);
        }
        var getIntentMethod = dropInRequest.getClass().getMethod("getIntent", [android.content.Context.class]);
        var clientTokenMethod = dropInRequest.getClass().getMethod("clientToken", [java.lang.String.class]);
        var isAndroidPayEnabled = dropInRequest.getClass().getMethod("isAndroidPayEnabled", []);
        var booleanType = isAndroidPayEnabled.getReturnType();
        if (options.collectDeviceData) {
            var collectDeviceDataMethod = dropInRequest.getClass().getMethod("collectDeviceData", [booleanType]);
            collectDeviceDataMethod.invoke(dropInRequest, [true]);
        }
        if (options.requestThreeDSecureVerification) {
            var requestThreeDSecureVerificationMethod = dropInRequest.getClass().getMethod("requestThreeDSecureVerification", [booleanType]);
            requestThreeDSecureVerificationMethod.invoke(dropInRequest, [true]);
        }
        if (options.enableGooglePay) {
            t.enableGooglePay(dropInRequest, options);
        }
        clientTokenMethod.invoke(dropInRequest, [token]);
        var dIRIntent = getIntentMethod.invoke(dropInRequest, [activity]);
        this.callIntent(dIRIntent);
    };
    Braintree.prototype.callIntent = function (intent) {
        var t = this;
        app.android.foregroundActivity.startActivityForResult(intent, 4949);
        app.android.on(app.AndroidApplication.activityResultEvent, onResult);
        function onResult(args) {
            app.android.off(app.AndroidApplication.activityResultEvent, onResult);
            t.handleResults(args.requestCode, args.resultCode, args.intent);
        }
    };
    Braintree.prototype.handleResults = function (requestCode, resultCode, data) {
        var t = this;
        var androidAcivity = android.app.Activity;
        if (requestCode === 4949) {
            if (resultCode === androidAcivity.RESULT_OK) {
                var result = data.getParcelableExtra(com.braintreepayments.api.dropin.DropInResult.EXTRA_DROP_IN_RESULT);
                var paymentMethodNonce = result.getPaymentMethodNonce().getNonce();
                if (typeof result.paymentMethod == null) {
                    t.output.status = 'error';
                    t.output.msg = 'Nonce Value empty';
                    setTimeout(function () {
                        t.notify({
                            eventName: 'error',
                            object: t
                        });
                    });
                    return;
                }
                t.output.status = 'success';
                t.output.msg = 'Got Payment Nonce Value';
                t.output.nonce = paymentMethodNonce;
                t.output.deviceInfo = result.getDeviceData();
                t.output.paymentMethodType = result.getPaymentMethodType().getCanonicalName();
                setTimeout(function () {
                    t.notify({
                        eventName: 'success',
                        object: t
                    });
                });
            }
            else if (resultCode === androidAcivity.RESULT_CANCELED) {
                t.output.status = 'cancelled';
                t.output.msg = 'User has cancelled payment';
                setTimeout(function () {
                    t.notify({
                        eventName: 'cancel',
                        object: t
                    });
                });
            }
            else {
                var exception_1 = data.getSerializableExtra(com.braintreepayments.api.dropin.DropInActivity.EXTRA_ERROR);
                t.output.msg = exception_1.getMessage();
                setTimeout(function () {
                    t.notify({
                        eventName: 'error',
                        object: t
                    });
                });
            }
        }
    };
    Braintree.prototype.enableGooglePay = function (dropInRequest, options) {
        var GooglePaymentRequest = com.braintreepayments.api.models.GooglePaymentRequest;
        var TransactionInfo = com.google.android.gms.wallet.TransactionInfo;
        var WalletConstants = com.google.android.gms.wallet.WalletConstants;
        var googlePaymentRequest = new GooglePaymentRequest()
            .transactionInfo(TransactionInfo.newBuilder()
            .setTotalPrice(options.amount)
            .setTotalPriceStatus(WalletConstants.TOTAL_PRICE_STATUS_FINAL)
            .setCurrencyCode(options.currencyCode)
            .build())
            .billingAddressRequired(true);
        dropInRequest.googlePaymentRequest(googlePaymentRequest);
    };
    return Braintree;
}(observable_1.Observable));
exports.Braintree = Braintree;
//# sourceMappingURL=braintree.android.js.map