"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var observable_1 = require("tns-core-modules/data/observable");
var setupAppDeligate = require('./getappdelegate').setupAppDeligate;
function setupBraintreeAppDeligate(urlScheme) {
    setupAppDeligate(urlScheme);
}
exports.setupBraintreeAppDeligate = setupBraintreeAppDeligate;
var Braintree = (function (_super) {
    __extends(Braintree, _super);
    function Braintree() {
        var _this = _super.call(this) || this;
        _this.output = {
            'status': 'fail',
            'msg': 'unknown',
            'nonce': '',
            'paymentMethodType': '',
            'deviceInfo': ''
        };
        return _this;
    }
    Braintree.prototype.startPayment = function (token, options) {
        var _this = this;
        var request = BTDropInRequest.alloc().init();
        if (options.amount) {
            request.amount = options.amount;
        }
        if (options.collectDeviceData) {
            request.collectDeviceData = true;
        }
        if (options.requestThreeDSecureVerification) {
            request.threeDSecureVerification = true;
        }
        var dropIn = BTDropInController.alloc().initWithAuthorizationRequestHandler(token, request, function (controller, result, error) {
            if (error !== null) {
                setTimeout(function () {
                    _this.notify({
                        eventName: 'error',
                        object: _this
                    });
                });
            }
            else if (result.cancelled) {
                _this.output.status = 'cancelled';
                _this.output.msg = 'User has cancelled payment';
                setTimeout(function () {
                    _this.notify({
                        eventName: 'cancel',
                        object: _this
                    });
                });
            }
            else {
                if (typeof result.paymentMethod == null) {
                    _this.output.status = 'error';
                    _this.output.msg = 'Nonce Value empty';
                    setTimeout(function () {
                        _this.notify({
                            eventName: 'error',
                            object: _this
                        });
                    });
                    return;
                }
                if (result.paymentDescription === "Apple Pay") {
                    var request_1 = PKPaymentRequest.alloc().init();
                    request_1.paymentSummaryItems = options.applePayPaymentRequest.paymentSummaryItems;
                    request_1.countryCode = options.applePayPaymentRequest.countryCode;
                    request_1.currencyCode = options.applePayPaymentRequest.currencyCode;
                    request_1.merchantIdentifier = options.applePayPaymentRequest.merchantIdentifier;
                    request_1.merchantCapabilities = options.applePayPaymentRequest.merchantCapabilities;
                    request_1.supportedNetworks = options.applePayPaymentRequest.supportedNetworks;
                    console.log("canMakePayments(): " + PKPaymentAuthorizationViewController.canMakePayments());
                    console.log("canMakePaymentsUsingNetworks(): " + PKPaymentAuthorizationViewController.canMakePaymentsUsingNetworks(request_1.supportedNetworks));
                    console.log("canMakePaymentsUsingNetworksCapabilities(): " + PKPaymentAuthorizationViewController.canMakePaymentsUsingNetworksCapabilities(request_1.supportedNetworks, request_1.merchantCapabilities));
                    var applePayController = PKPaymentAuthorizationViewController.alloc().initWithPaymentRequest(request_1);
                    var pkPaymentDelegateImpl = new PKPaymentAuthorizationViewControllerDelegateImpl();
                    var applePayClient = new BTApplePayClient(dropIn.apiClient);
                    pkPaymentDelegateImpl.applePayClient = applePayClient;
                    pkPaymentDelegateImpl.braintree = _this;
                    try {
                        applePayController.delegate = pkPaymentDelegateImpl;
                    }
                    catch (error) {
                        console.log("Initialization of PKPaymentAuthorizationViewController failed");
                        var alertController = UIAlertController.alertControllerWithTitleMessagePreferredStyle("Error", "An error has occurred, please try again or use a different payment method.", 1);
                        alertController.addAction(UIAlertAction.actionWithTitleStyleHandler("Ok", 0, null));
                        controller.presentViewControllerAnimatedCompletion(alertController, true, null);
                        return;
                    }
                    console.log("applePayController: " + applePayController);
                    console.log("delegateImpl: " + pkPaymentDelegateImpl);
                    _this.dropInController = controller;
                    controller.presentViewControllerAnimatedCompletion(applePayController, true, function () {
                    });
                    return;
                }
                else {
                    _this.output.nonce = result.paymentMethod.nonce;
                    _this.output.paymentMethodType = result.paymentMethod.type;
                    _this.output.status = 'success';
                    _this.output.msg = 'Got Payment Nonce Value';
                    _this.output.deviceInfo = PPDataCollector.collectPayPalDeviceData();
                    setTimeout(function () {
                        _this.notify({
                            eventName: 'success',
                            object: _this
                        });
                    });
                }
            }
            controller.dismissViewControllerAnimatedCompletion(true, null);
        });
        var app = UIApplication.sharedApplication;
        app.keyWindow.rootViewController.presentViewControllerAnimatedCompletion(dropIn, true, null);
    };
    Braintree.prototype.submitApplePayment = function (applePayNonce) {
        var _this = this;
        this.output.nonce = applePayNonce;
        this.output.paymentMethodType = "18";
        this.output.status = 'success';
        this.output.msg = 'Got Payment Nonce Value';
        this.output.deviceInfo = PPDataCollector.collectPayPalDeviceData();
        this.dropInController.dismissViewControllerAnimatedCompletion(true, null);
        setTimeout(function () {
            _this.notify({
                eventName: 'success',
                object: _this
            });
        });
    };
    return Braintree;
}(observable_1.Observable));
exports.Braintree = Braintree;
var PKPaymentAuthorizationViewControllerDelegateImpl = (function (_super) {
    __extends(PKPaymentAuthorizationViewControllerDelegateImpl, _super);
    function PKPaymentAuthorizationViewControllerDelegateImpl() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidAuthorizePaymentCompletion = function (controller, payment, completion) {
        var _this = this;
        console.log("PaymentAuthorizationViewController Did Authorize Payment Completion executing");
        this.applePayClient.tokenizeApplePayPaymentCompletion(payment, function (nonce, error) {
            if (nonce) {
                _this.nonce = nonce;
                completion(0);
            }
            else {
                completion(1);
                console.dir("#####################");
                console.log("error: " + error);
                console.dir("#####################");
            }
        });
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidAuthorizePaymentHandler = function (controller, payment, completion) {
        var _this = this;
        console.log("PaymentAuthorizationViewController Did Authorize Payment Handler executing");
        var result = PKPaymentAuthorizationResult.alloc().init();
        this.applePayClient.tokenizeApplePayPaymentCompletion(payment, function (nonce, error) {
            if (nonce) {
                _this.nonce = nonce;
                result.status = 0;
                completion(result);
            }
            else {
                result.status = 1;
                completion(result);
                console.dir("#####################");
                console.log("error: " + error);
                console.dir("#####################");
            }
        });
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidFinish = function (controller) {
        console.log("paymentAuthorizationViewControllerDidFinish(" + controller + ")");
        if (!this.nonce) {
            controller.dismissViewControllerAnimatedCompletion(true, null);
        }
        else {
            this.braintree.submitApplePayment(this.nonce.nonce);
            this.braintree.dropInController.dismissViewControllerAnimatedCompletion(true, null);
        }
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidSelectPaymentMethodCompletion = function (controller, paymentMethod, completion) {
        console.log("paymentAuthorizationViewControllerDidSelectPaymentMethodCompletion Method not implemented 4.");
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidSelectPaymentMethodHandler = function (controller, paymentMethod, completion) {
        var paymentMethodUpdate = PKPaymentRequestPaymentMethodUpdate.alloc().init();
        completion(paymentMethodUpdate);
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidSelectShippingAddressCompletion = function (controller, address, completion) {
        console.log("paymentAuthorizationViewControllerDidSelectShippingAddressCompletion Method not implemented 6.");
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidSelectShippingContactCompletion = function (controller, contact, completion) {
        console.log("paymentAuthorizationViewControllerDidSelectShippingAddressCompletion Method not implemented 7.");
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidSelectShippingContactHandler = function (controller, contact, completion) {
        console.log("paymentAuthorizationViewControllerDidSelectShippingContactHandler Method not implemented 8.");
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidSelectShippingMethodCompletion = function (controller, shippingMethod, completion) {
        console.log("paymentAuthorizationViewControllerDidSelectShippingMethodCompletion Method not implemented 9.");
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerDidSelectShippingMethodHandler = function (controller, shippingMethod, completion) {
        console.log("paymentAuthorizationViewControllerDidSelectShippingMethodHandler Method not implemented 10.");
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.prototype.paymentAuthorizationViewControllerWillAuthorizePayment = function (controller) {
        console.log("paymentAuthorizationViewControllerWillAuthorizePayment Method not implemented 11.");
    };
    PKPaymentAuthorizationViewControllerDelegateImpl.ObjCProtocols = [PKPaymentAuthorizationViewControllerDelegate];
    return PKPaymentAuthorizationViewControllerDelegateImpl;
}(NSObject));
exports.PKPaymentAuthorizationViewControllerDelegateImpl = PKPaymentAuthorizationViewControllerDelegateImpl;
//# sourceMappingURL=braintree.ios.js.map